ApplyAuthFormModel class

Constructors

ApplyAuthFormModel({required String phoneNumber, required bool isPrivacyAgreed, required bool isServiceAgreed, required bool enabled, required bool pending})
const

Properties

enabled bool
final
hashCode int
The hash code for this object.
no setterinherited
isPrivacyAgreed bool
final
isServiceAgreed bool
final
pending bool
final
phoneNumber String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copy({String? phoneNumber, bool? isPrivacyAgreed, bool? isServiceAgreed, bool? enabled, bool? pending}) ApplyAuthFormModel
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited