CouponModel class

Constructors

CouponModel({required String id, required String name, required String issuerId, required String ownerId, required int discount, required int minimum, required DateTime expires, required CouponState state, required DateTime? usedAt, required DateTime updatedAt, required DateTime createdAt})
const
CouponModel.fromjson(dynamic json)
factory

Properties

createdAt DateTime
final
discount int
final
expires DateTime
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
issuerId String
final
minimum int
final
name String
final
ownerId String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state CouponState
final
updatedAt DateTime
final
usedAt DateTime?
final

Methods

copy({String? id, String? name, String? issuerId, String? ownerId, int? discount, int? minimum, CouponState? state, Option<DateTime>? usedAt, DateTime? expires, DateTime? updatedAt, DateTime? createdAt}) CouponModel
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

stateFromJson(dynamic json) CouponState