ItemOptionModel class

Implementers

Constructors

ItemOptionModel({required String id, required String itemId, required String label, required DateTime updatedAt, required DateTime createdAt})
const
ItemOptionModel.fromJson(dynamic json)
factory

Properties

createdAt DateTime
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
itemId String
final
label String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
updatedAt DateTime
final

Methods

copy({String? id, String? label, String? itemId, DateTime? updatedAt, DateTime? createdAt}) ItemOptionModel
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited