OrderedItemOption class

Implementers

Constructors

OrderedItemOption({required String id, required String label})
const
OrderedItemOption.fromJson(dynamic json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
id String
final
label String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited