UserModel class

Constructors

UserModel({required String id, required String phoneNumber, required DateTime updatedAt, required DateTime createdAt})
const
UserModel.fromJson(dynamic json)
factory

Properties

createdAt DateTime
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
phoneNumber String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
updatedAt DateTime
final

Methods

copy({String? id, String? phoneNumber, DateTime? updatedAt, DateTime? createdAt}) UserModel
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited