OrderedSelectionItemOption class
- Inheritance
-
- Object
- OrderedItemOption
- OrderedSelectionItemOption
Constructors
- OrderedSelectionItemOption({required String id, required String label, required SelectionElementModel selection})
-
const
- OrderedSelectionItemOption.fromJson(dynamic json)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
finalinherited
- label → String
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selection → SelectionElementModel
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited